@@ -18,20 +18,41 @@
             utils::packageDescription("dtwSat")$Version) )
 }
 
+
+#' @import zoo 
+#' @import raster 
+#' @import ggplot2
 #' @import methods
-#' @import dtw
-#' @import zoo
 #' @importFrom proxy dist
 #' @importFrom reshape2 melt
-#' @importFrom graphics plot
-#' @importFrom waveslim mra
-#' @importFrom ggplot2 ggplot geom_line geom_point geom_path geom_raster geom_polygon xlab ylab scale_x_continuous scale_y_continuous scale_x_date scale_y_date scale_fill_brewer annotate scale_fill_gradientn aes_string waiver autoplot
-#' @importFrom scales pretty_breaks
+#' @importFrom scales pretty_breaks date_format percent
 #' @importFrom grDevices terrain.colors gray.colors
-#' @importFrom utils tail head
-#'
+#' @importFrom plyr alply
+#' @importFrom parallel mclapply
+#' @importFrom sp Polygon Polygons SpatialPoints SpatialPolygons SpatialPointsDataFrame over CRS spTransform coordinates bbox 
+#' @importFrom mgcv gam predict.gam 
+#' @importFrom RColorBrewer brewer.pal 
+#' @importFrom stats xtabs ave window na.omit
+#' @importFrom lubridate month month<- day day<- year year<-
+#' @importFrom caret createDataPartition 
+#' 
 NULL
 
 
+### Import and export functions from other packages
 
+#' @importFrom dtw symmetric1
+#' @export 
+dtw::symmetric1
 
+#' @importFrom dtw symmetric2 
+#' @export 
+dtw::symmetric2
+
+#' @importFrom dtw asymmetric 
+#' @export 
+dtw::asymmetric
+
+#' @importFrom dtw rabinerJuangStepPattern 
+#' @export 
+dtw::rabinerJuangStepPattern
